developerscripttools.CleanScript
================================

.. inheritance-diagram:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.alias

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.argument_parser

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_help

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_usage

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.formatted_version

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.program_name

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.process_args

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__call__

    Inherited from :py:class:`developerscripttools.DeveloperScript <abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.CleanScript.CleanScript.CleanScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
